@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
-// Copyright (c) 1996-2003 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // Generic Hash Table
 // Implementation
 
@@ -34,7 +34,8 @@ void* HashTable::RemoveNext() {
   Iterator* iter = Iterator::create(*this);
   char const* key;
   void* removedValue = iter->next(key);
-  Remove(key);
+  if (removedValue != 0) Remove(key);
 
+  delete iter;
   return removedValue;
 }
