@@ -13,12 +13,17 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
-// Copyright (c) 1996-2000 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // Usage Environment
 // Implementation
 
 #include "UsageEnvironment.hh"
 
+void UsageEnvironment::reclaim() {
+  // We delete ourselves only if we have no remainining state:
+  if (liveMediaPriv == NULL && groupsockPriv == NULL) delete this;
+}
+
 UsageEnvironment::UsageEnvironment(TaskScheduler& scheduler)
   : liveMediaPriv(NULL), groupsockPriv(NULL), fScheduler(scheduler) {
 }
@@ -32,3 +37,9 @@ TaskScheduler::TaskScheduler() {
 TaskScheduler::~TaskScheduler() {
 }
  
+void TaskScheduler::rescheduleDelayedTask(TaskToken& task,
+					  int64_t microseconds, TaskFunc* proc,
+					  void* clientData) {
+  unscheduleDelayedTask(task);
+  task = scheduleDelayedTask(microseconds, proc, clientData);
+}
