@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
-// Copyright (c) 1996-2007 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // 'Group sockets'
 // Implementation
 
@@ -122,7 +122,7 @@ Groupsock::Groupsock(UsageEnvironment& env, struct in_addr const& groupAddr,
   }
   
   // Make sure we can get our source address:
-  if (ourSourceAddressForMulticast(env) == 0) {
+  if (ourIPAddress(env) == 0) {
     if (DebugLevel >= 0) { // this is a fatal error
       env << "Unable to determine our source address: "
 	  << env.getResultMsg() << "\n";
@@ -274,7 +274,7 @@ Boolean Groupsock::output(UsageEnvironment& env, u_int8_t ttlToSend,
       numMembers =
 	outputToAllMembersExcept(interfaceNotToFwdBackTo,
 				 ttlToSend, buffer, bufferSize,
-				 ourSourceAddressForMulticast(env));
+				 ourIPAddress(env));
       if (numMembers < 0) break;
     }
     
@@ -353,7 +353,7 @@ Boolean Groupsock::handleRead(unsigned char* buffer, unsigned bufferMaxSize,
 Boolean Groupsock::wasLoopedBackFromUs(UsageEnvironment& env,
 				       struct sockaddr_in& fromAddress) {
   if (fromAddress.sin_addr.s_addr
-      == ourSourceAddressForMulticast(env)) {
+      == ourIPAddress(env)) {
     if (fromAddress.sin_port == sourcePortNum()) {
 #ifdef DEBUG_LOOPBACK_CHECKING
       if (DebugLevel >= 3) {
