@@ -14,13 +14,14 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "mTunnel" multicast access service
-// Copyright (c) 1996-1998 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // Network Interfaces
 // Implementation
 
 #include "NetInterface.hh"
 #include "GroupsockHelper.hh"
 
+#ifndef NO_STRSTREAM
 #if (defined(__WIN32__) || defined(_WIN32)) && !defined(__MINGW32__)
 #include <strstrea.h>
 #else
@@ -30,6 +31,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 #include <strstream.h>
 #endif
 #endif
+#endif
 
 ////////// NetInterface //////////
 
@@ -91,12 +93,18 @@ DirectedNetInterface* DirectedNetInterfaceSet::Iterator::next() {
 int Socket::DebugLevel = 1; // default value
 
 Socket::Socket(UsageEnvironment& env, Port port, Boolean setLoopback)
-	: fEnv(DefaultUsageEnvironment != NULL ? *DefaultUsageEnvironment : env), fPort(port) {
-	fSocketNum = setupDatagramSocket(fEnv, port, setLoopback);
+  : fEnv(DefaultUsageEnvironment != NULL ? *DefaultUsageEnvironment : env), fPort(port), fSetLoopback(setLoopback) {
+  fSocketNum = setupDatagramSocket(fEnv, port, setLoopback);
 }
 
 Socket::~Socket() {
-	_close(fSocketNum);
+  closeSocket(fSocketNum);
+}
+
+Boolean Socket::changePort(Port newPort) {
+  closeSocket(fSocketNum);
+  fSocketNum = setupDatagramSocket(fEnv, newPort, fSetLoopback);
+  return fSocketNum >= 0;
 }
 
 UsageEnvironment& operator<<(UsageEnvironment& s, const Socket& sock) {
